@@ -105,7 +105,8 @@ show_mettrndseason <- function(mod, metfun = mean, doystr = 1, doyend = 364, jus
   # plot output
   p <- ggplot2::ggplot(data = toplo, ggplot2::aes(x = yr, y = bt_met)) + 
     ggplot2::geom_errorbar(ggplot2::aes(ymin = bt_lwr, ymax = bt_upr), colour = 'black', width = width, na.rm = TRUE) +
-    ggplot2::geom_point(ggplot2::aes(fill = trnd), pch = 21, color = 'black', size = size, na.rm = TRUE) +
+    ggplot2::geom_point(ggplot2::aes(fill = trnd), pch = 21, color = 'black', 
+      size = size, na.rm = TRUE, show.legend = TRUE) +
     ggplot2::theme_bw(base_size = base_size) +
     ggplot2::scale_fill_manual(values = fils, drop = F) +
     ggplot2::theme(
