@@ -18,4 +18,14 @@ test_that("Checking  error, insufficient inputs", {
   
   expect_error(anlz_avgseason(doystr = 90, doyend = 180))
   
-})
\ No newline at end of file
+})
+
+test_that("Checking yromit", {
+  
+  result <- anlz_avgseason(mod, doystr = 90, doyend = 180, yromit = 2016)
+  
+  # excpect NA for 2016
+  expected <- na.omit(result)$yr
+  expect_equal(expected, c(2017, 2018, 2019))
+  
+})
