@@ -1,14 +1,17 @@
 test_that("Checking multiple parameters in anlz_gam", {
  
-  rawdat <- rawdat %>% dplyr::filter(station %in% 32)
-  expect_error(anlz_gam(rawdat), 'More than one parameter found in input data')
+  rawdatchk <- rawdat %>% dplyr::filter(station %in% 32)
+  expect_error(anlz_gam(rawdatchk), 'More than one parameter found in input data')
   
 })
 
 test_that("Checking multiple stations anlz_gam", {
   
-  rawdat <- rawdat %>% dplyr::filter(param %in% 'chl')
-  expect_error(anlz_gam(rawdat), 'More than one station found in input data')
+  rawdatchk <- rawdat %>% 
+    dplyr::filter(param %in% 'chl') %>% 
+    dplyr::filter(yr > 2015) %>% 
+    dplyr::filter(station %in% c(32, 34))
+  expect_error(anlz_gam(rawdatchk), 'More than one station found in input data')
   
 })
 
